# VTScan
Utility to scan for malicious files using the VirusTotal API

# Installation

pip install vtscan

# Usage

vtscan </path/to/filename>

# Notes

It will prompt you to register a free account at [https://www.virustotal.com ](https://www.virustotal.com ) when you run for the first time. Then, you'll have to get your API Key and put it in the `config.json` in order for the scanning script to work.
